
# Slot: paralogous to


a homology relationship that holds between entities (typically genes) that diverged after a duplication event.

URI: [biolink:paralogous_to](https://w3id.org/biolink/vocab/paralogous_to)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [homologous to](homologous_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:HOM0000011 |

